
Installation
============

Installation is easy using ``pip`` or ``easy_install``.

.. code-block:: bash

	pip install django-concepts

or
.. code-block:: bash

	easy_install django-concepts

Dependencies
************
